@@ -1,18 +1,23 @@
 package Sah::Schema::unix::local_gid;
 
 our $DATE = '2019-05-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
-our $schema = [uint => {
-    summary => 'Group identifier (GID) that has to exist (has associated group name) on the system',
+our $schema = ["unix::gid" => {
+    summary => 'Group identifier (GID) that has to exist on the system',
     description => <<'_',
 
+Existing means having a group name associated with this GID, i.e. `getgrgid`
+returns a record.
+
+Support coercion from an existing group name.
+
 _
     'x.perl.coerce_rules' => ['str_convert_unix_group_to_gid', 'int_check_gid_exists'],
 }, {}];
 
 1;
-# ABSTRACT: Group identifier (GID) that has to exist (has associated group name) on the system
+# ABSTRACT: Group identifier (GID) that has to exist on the system
 
 __END__
 
@@ -22,14 +27,19 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::unix::local_gid - Group identifier (GID) that has to exist (has associated group name) on the system
+Sah::Schema::unix::local_gid - Group identifier (GID) that has to exist on the system
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::unix::local_gid (from Perl distribution Sah-Schemas-Unix), released on 2019-05-07.
+This document describes version 0.003 of Sah::Schema::unix::local_gid (from Perl distribution Sah-Schemas-Unix), released on 2019-05-07.
 
 =head1 DESCRIPTION
 
+Existing means having a group name associated with this GID, i.e. C<getgrgid>
+returns a record.
+
+Support coercion from an existing group name.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Unix>.
