@@ -1,10 +1,15 @@
 package Sah::Schema::unix::local_groupname;
 
 our $DATE = '2019-05-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = ['unix::groupname' => {
     summary => 'Unix group name that must exist on the system',
+    description => <<'_',
+
+Support coercion from GID.
+
+_
     'x.perl.coerce_rules' => ['int_convert_gid_to_unix_group', 'str_check_unix_group_exists'],
 }, {}];
 
@@ -23,7 +28,11 @@ Sah::Schema::unix::local_groupname - Unix group name that must exist on the syst
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::unix::local_groupname (from Perl distribution Sah-Schemas-Unix), released on 2019-05-07.
+This document describes version 0.003 of Sah::Schema::unix::local_groupname (from Perl distribution Sah-Schemas-Unix), released on 2019-05-07.
+
+=head1 DESCRIPTION
+
+Support coercion from GID.
 
 =head1 HOMEPAGE
 
