@@ -1,12 +1,17 @@
 package Sah::Schema::unix::local_uid;
 
 our $DATE = '2019-05-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
-our $schema = [uint => {
+our $schema = ["unix::uid" => {
     summary => 'User identifier (UID) that has to exist (has associated username) on the system',
     description => <<'_',
 
+Existing means having a user name associated with this UID, i.e. `getpwuid`
+returns a record.
+
+Support coercion from an existing user name.
+
 _
     'x.perl.coerce_rules' => ['str_convert_unix_user_to_uid', 'int_check_uid_exists'],
 }, {}];
@@ -26,10 +31,15 @@ Sah::Schema::unix::local_uid - User identifier (UID) that has to exist (has asso
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::unix::local_uid (from Perl distribution Sah-Schemas-Unix), released on 2019-05-07.
+This document describes version 0.003 of Sah::Schema::unix::local_uid (from Perl distribution Sah-Schemas-Unix), released on 2019-05-07.
 
 =head1 DESCRIPTION
 
+Existing means having a user name associated with this UID, i.e. C<getpwuid>
+returns a record.
+
+Support coercion from an existing user name.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Unix>.
