@@ -1,10 +1,15 @@
 package Sah::Schema::unix::local_username;
 
 our $DATE = '2019-05-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = ['unix::username' => {
     summary => 'Unix user name that must exist on the system',
+    description => <<'_',
+
+Support coercion from UID.
+
+_
     'x.perl.coerce_rules' => ['int_convert_uid_to_unix_user', 'str_check_unix_user_exists'],
 }, {}];
 
@@ -23,7 +28,11 @@ Sah::Schema::unix::local_username - Unix user name that must exist on the system
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::unix::local_username (from Perl distribution Sah-Schemas-Unix), released on 2019-05-07.
+This document describes version 0.003 of Sah::Schema::unix::local_username (from Perl distribution Sah-Schemas-Unix), released on 2019-05-07.
+
+=head1 DESCRIPTION
+
+Support coercion from UID.
 
 =head1 HOMEPAGE
 
